"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.prettierConfigCreator = void 0;
const creator_utils_1 = require("@knapsack/creator-utils");
const path_1 = require("path");
const { pkg } = (0, creator_utils_1.findUpPkgJson)(__dirname);
exports.prettierConfigCreator = (0, creator_utils_1.createCreator)({
    id: 'prettier-config',
    getQuestions: async () => ({
        addIgnore: {
            type: 'boolean',
            title: 'Add .prettierignore file?',
            default: false,
        },
    }),
    getTasks: async ({ answers: { addIgnore }, config: { dest } }) => {
        const { pkgPath, pkgDir } = (0, creator_utils_1.findUpPkgJson)(dest);
        return [
            {
                title: 'Update package.json',
                task: async () => creator_utils_1.tasks.updatePkgJson({
                    dir: pkgDir,
                    pkg: {
                        devDependencies: {
                            [pkg.name]: pkg.version,
                        },
                    },
                }),
            },
            {
                title: 'Add prettier config',
                skip: (0, creator_utils_1.hasFileUp)({
                    cwd: dest,
                    file: [
                        '.prettierrc',
                        '.prettierrc.json',
                        'prettier.config.json',
                        'prettier.config.js',
                    ],
                }),
                task: async (ctx, task) => {
                    const msg = await creator_utils_1.tasks.addFile({
                        contents: [
                            `const config = require('${pkg.name}');`,
                            '',
                            `module.exports = config;`,
                        ],
                        destination: (0, path_1.join)(dest, 'prettier.config.js'),
                        handlePriorFile: 'overwrite',
                    });
                    task.title = msg;
                    return msg;
                },
            },
            {
                title: 'Add .prettierignore',
                skip: !addIgnore ||
                    (0, creator_utils_1.hasFileUp)({
                        cwd: dest,
                        file: ['.prettierignore'],
                    }),
                task: async () => creator_utils_1.tasks.addFile({
                    destination: (0, path_1.join)(dest, '.prettierignore'),
                    handlePriorFile: 'skip',
                    contents: ['node_modules', 'dist'],
                }),
            },
        ];
    },
});
//# sourceMappingURL=prettier-config-creator.js.map